<?php

require_once('StorageInterface.php');
require_once('language_dependencies/LanguageInterface.php');

/**
 * Methods for database handling.
 */
class DB extends SQLite3 implements StorageInterface{

    const DATABASE = 'data.db';

    private $language;

    /**
     * DB class constructor. Initialize method is called, which will create data table if
     * it does not exist already.
     */
    public function __construct(LanguageInterface $language) {
        $this->open(self::DATABASE);
        $this->initialize();
        $this->language = $language;
    }

    /**
     * Craetes the table if it does not exist already.
     */
    protected function initialize() {
        $sql = 'CREATE TABLE IF NOT EXISTS data (
                    data STRING
                )';

        $this->exec($sql);
    }

    /**
     * Inserts the data into the databse.
     *
     * @param $data Data to insert.
     */
    public function writeData($data) {
        $contents = $this->language->getInfoString() . ' ' . $data;

        $sql = 'INSERT INTO data
                VALUES (:contents)';

        $statement = $this->prepare($sql);
        $statement->bindValue(':contents', $contents);

        $statement->execute();

        $statement->close();
    }

    /**
     * Selects data from database.
     *
     * @return Database data.
     */
    public function readData() {
        $sql = 'SELECT data
                FROM   data';

        $results = $this->query($sql);

        $data = '';

        while ($row = $results->fetchArray()) {
            $data .= $row['data'] . '<br>';
        }

        return $data;
    }
}
